@@ -23,6 +23,7 @@ class PGCompleter(Completer):
 
     special_commands = []
 
+    database_names = []
     table_names = []
     column_names = ['*']
     all_completions = set(keywords)
@@ -32,8 +33,13 @@ class PGCompleter(Completer):
         self.smart_completion = smart_completion
 
     def extend_special_commands(self, special_commands):
+        # Special commands are not part of all_completions since they can only
+        # be at the beginning of a line.
         self.special_commands.extend(special_commands)
 
+    def extend_database_names(self, database_names):
+        self.database_names.extend(database_names)
+
     def extend_keywords(self, additional_keywords):
         self.keywords.extend(additional_keywords)
         self.all_completions.update(additional_keywords)
@@ -61,6 +67,8 @@ class PGCompleter(Completer):
 
         word_before_cursor = document.get_word_before_cursor(WORD=True)
 
+        # If smart_completion is off then match any word that starts with
+        # 'word_before_cursor'.
         if not self.smart_completion:
             return self.find_matches(word_before_cursor, self.all_completions)
 
@@ -86,6 +94,10 @@ class PGCompleter(Completer):
             return self.find_matches(word_before_cursor, self.column_names)
         elif last_token.lower() in ('from', 'update', 'into'):
             return self.find_matches(word_before_cursor, self.table_names)
+        elif last_token in ('d', 'describe'):  # This for the \d special command.
+            return self.find_matches(word_before_cursor, self.table_names)
+        elif last_token in ('c',):  # This for the \c special command.
+            return self.find_matches(word_before_cursor, self.database_names)
         else:
             return self.find_matches(word_before_cursor,
                     self.keywords + self.special_commands)
